@@ -3,10 +3,10 @@ package operatorclient
 import (
 	"fmt"
 
-	"github.com/golang/glog"
 	v1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/types"
+	"k8s.io/klog"
 )
 
 // CreateService creates the Service.
@@ -26,7 +26,7 @@ func (c *Client) DeleteService(namespace, name string, options *metav1.DeleteOpt
 
 // UpdateService will update the given Service resource.
 func (c *Client) UpdateService(service *v1.Service) (*v1.Service, error) {
-	glog.V(4).Infof("[UPDATE Service]: %s", service.GetName())
+	klog.V(4).Infof("[UPDATE Service]: %s", service.GetName())
 	oldSa, err := c.GetService(service.GetNamespace(), service.GetName())
 	if err != nil {
 		return nil, err
